@@ -11,7 +11,7 @@ import pandas as pd
 
 class GSDBS:
     def __init__(self):
-        self.version = "0.1.14"
+        self.version = "0.1.17"
         self.credentials = None
         self.accessToken = None
         self.dtablename = None
@@ -23,8 +23,12 @@ class GSDBS:
         self.getToken()
         self.CGSResponseCode = {}
         self.setupCGSResponseCodes()
+        self.debugModus = False
         return
 
+    def setDebugModus(self, debugModus):
+        self.debugModus = debugModus
+
     def readCredentials(self):
         try:
             print(f'GS-DBMS Python client version: {self.version}')
@@ -66,6 +70,9 @@ class GSDBS:
         self.CGSResponseCode['-7'] = 'DATAFRAME DATATYPE DOESN\'T MATCHES DTABEL DATATYPE'
         self.CGSResponseCode['-8'] = 'EXECUTION FAILED'
         self.CGSResponseCode['-9'] = 'MISSING STATEMENT TO EXECUTE'
+        self.CGSResponseCode['-10'] = 'STATEMENT ERROR'
+        self.CGSResponseCode['-11'] = 'ERROR IN DATASCHEMA'
+        self.CGSResponseCode['-12'] = 'TYPE ERROR'
 
     def setDTableName(self, dTableName, superDTableName="DTABLE"):
         if dTableName is None or superDTableName is None:
@@ -164,6 +171,8 @@ class GSDBS:
             return "DATETIME"
         elif pyType == "datetime64":
             return "DATETIME"
+        elif pyType == "datetime64[ns]":
+            return "DATETIME"
         else:
             return None
 
@@ -172,7 +181,7 @@ class GSDBS:
         for col in self.data:
             gsDbsType = self.getGSDBSType(str(self.data.dtypes[col]))
             if gsDbsType == None:
-                return -1
+                return -12
             s += f"""\t\t\t{{alias: "{col}", locale: DE, superPropertyURI: DYNAMIC_DATALINK, DataType: {gsDbsType}}},\n"""
         if len(s) > 0:
             s = s[:-2]
@@ -209,11 +218,23 @@ class GSDBS:
     def checkData(self):
         if (self.data is None):
             return -4
+        for col in self.data:
+            gsDbsType = self.getGSDBSType(str(self.data.dtypes[col]))
+            if gsDbsType == None:
+                return -12
         return 0
 
     def generateMutationStatement(self):
+
+        buildInfo = self.getSriBuildInfo()
+        if buildInfo == None:
+            return
+        dataSchema = self.getDataSchema()
+        if dataSchema == None:
+            return
+
         self.statement = \
-            f"""mutation {{\n\taddDTable(dtablename: "{self.dtablename}", \n\t\tsuperDTable: [{self.superdtablename}], \n\t\tsriBuildInfo: "{self.getSriBuildInfo()}", \n\t\tdataLinks: [\n{self.getDataSchema()}\n\t\t], \n\t\tdata: [\n{self.getData()}\t\t]\n\t)\n}}"""
+            f"""mutation {{\n\taddDTable(dtablename: "{self.dtablename}", \n\t\tsuperDTable: [{self.superdtablename}], \n\t\tsriBuildInfo: "{buildInfo}", \n\t\tdataLinks: [\n{dataSchema}\n\t\t], \n\t\tdata: [\n{self.getData()}\t\t]\n\t)\n}}"""
         return
 
     # ---------
@@ -285,12 +306,18 @@ class GSDBS:
             if rc != 0: return rc
 
         self.generateMutationStatement()
+        if self.debugModus:
+            print(self.statement)
+
         try:
             rc = await self.asyncExecuteStatement()
-        except:
-            return None
+        except Exception as e:
+            print(e)
+            return e
+
         return rc
 
+
     def addDObject(self, dtablename, sribuildinfo, dataframe, superdtablename="DTABLE", schemaCheck=True):
         self.superdtablename = superdtablename
         rc = self.setDTableName(dtablename)
@@ -305,27 +332,38 @@ class GSDBS:
             if rc != 0: return rc
 
         self.generateMutationStatement()
+        if self.debugModus:
+            print(self.statement)
+
         try:
             rc = self.executeStatement()
-        except:
-            return None
+        except Exception as e:
+            print(e)
+            return e
+
         return rc
 
     # ---------
     async def asyncSchemaQuery(self, dtablename):
         statement = "{ __type(name: \"" + dtablename + "\") {name fields { name type { name kind } } } }"
+
         try:
             result = await self.asyncExecuteStatement(statement)
-        except:
-            return None
+        except Exception as e:
+            print(e)
+            return e
+
         return result
 
     def schemaQuery(self, dtablename):
         statement = "{ __type(name: \"" + dtablename + "\") {name fields { name type { name kind } } } }"
+
         try:
             result = self.executeStatement(statement)
-        except:
-            return None
+        except Exception as e:
+            print(e)
+            return e
+
         return result
 
     # ---------
@@ -340,10 +378,13 @@ class GSDBS:
         client = Client(transport=AIOHTTPTransport(url="https://glass-sphere-ai.de/gsgraphql",
                         headers=api_call_headers),
                         fetch_schema_from_transport=False)
+
         try:
             result = await client.execute_async(query)
-        except:
-            return None
+        except Exception as e:
+            print(e)
+            return e
+
         return result
 
     def executeStatement(self, statement=None):
@@ -357,10 +398,13 @@ class GSDBS:
         client = Client(transport=AIOHTTPTransport(url="https://glass-sphere-ai.de/gsgraphql",
                         headers=api_call_headers),
                         fetch_schema_from_transport=False)
+
         try:
             result = client.execute(query)
-        except:
-            return None
+        except Exception as e:
+            print(e)
+            return e
+
         return result
 
     async def asyncDropDTable(self, dtablename):
